/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages/productcomparison/ui/comparelink
 *
 * @revision		$Revision: 1.2.22.1 $
 */

define("de_epages/productcomparison/ui/comparelink", [
	"jquery",
	"de_epages",
	"util/storage",

	"jquery/ui/widget"
], function ($, de_epages, storage) {

	$.widget('ui.productcomparisonUiComparelink', {

		options: {
			maxItemNo:              8,
			productID:              undefined
		},

		_create: function(){
			var self = this.element,
				productID = this.options.productID;

			/* check product id */
			if (!this._check(productID, self)){
				return;
			}

			/* add 'click' event handler on associated 'Compare' link */
			self.on('click', $.proxy(function(event) {
				this._handleClick(event, self);
			}, this));
		},

		_check: function(productID) {
			if (productID === undefined || isNaN(parseInt(productID))){
				console.warn('ProductComparison: parameter \'productID\' and/or \'compare\' link missing; product comparison is removed from SF.');
				self.remove();
				return false;
			}
			return true;
		},

		_handleClick: function(event, target) {
			var productIDs = storage.sessionStorage('Product::ProductComparison') || [],
				url = target.attr('href');

			event.preventDefault();

			this._addProductToComparisonList(this.options.productID, productIDs);

			storage.sessionStorage('Product::ProductComparison', productIDs);

			$.each(productIDs, function(index, value){
				url += '&SelectedObjectID=' + value;
			});

			window.location = url;
		},

		_addProductToComparisonList: function(productID, productIDs) {
			var index = $.inArray(productID, productIDs);

			if (index > -1){  // deletes former occurrence
				productIDs.splice(index, 1);
			}

			productIDs.push(productID);

			while (productIDs.length > this.options.maxItemNo){
				productIDs.shift();
			}
		},

		destroy: function() {
			this.off('click');

			return this.Inherited(arguments);
		}

	});

	return de_epages;

});