use Test::More;
use strict;
use DE_EPAGES::TrustedShops::API::Constants qw ( %CERT_STATUS );
use DE_EPAGES::TrustedShops::API::TLE::TrustedShopsHandler;
use DE_EPAGES::Core::API::Script qw ( RunScript );

sub Main {
    testIsTSIDShowableAtSF();
    done_testing();
}

sub testIsTSIDShowableAtSF() {
    my $Package = DE_EPAGES::TrustedShops::API::TLE::TrustedShopsHandler->new();
    ## no critic qw(ProhibitLongLines)
    ok( $Package->IS_TSID_STATUS_SHOWABLE_AT_SF( '', [$CERT_STATUS{'PRODUCTION'}] ), 'One TS_ID with status LIVE will be shown at SF' );
    ok( $Package->IS_TSID_STATUS_SHOWABLE_AT_SF( '', [$CERT_STATUS{'TEST'}] ), 'One TS_ID with status TEST will be shown at SF' );
    ok( $Package->IS_TSID_STATUS_SHOWABLE_AT_SF( '', [$CERT_STATUS{'INTEGRATION'}] ), 'One TS_ID with status INTEGRATION will be shown at SF' );
    ok( !$Package->IS_TSID_STATUS_SHOWABLE_AT_SF( '', [$CERT_STATUS{'OTHER'}] ), 'One TS_ID with another status defined by TrustedShops, but different to the previous ones, will be hidden at SF' );
    ok( !$Package->IS_TSID_STATUS_SHOWABLE_AT_SF( '', [888] ), 'One TS_ID with any status not defined by TrustedShops will be hidden at SF' ); ## no critic qw(ProhibitMagicNumbers)
    ok( !$Package->IS_TSID_STATUS_SHOWABLE_AT_SF( '', ['abcde'] ), 'One TS_ID with status NOT_INTEGER will be hidden at SF' );
    ok( !$Package->IS_TSID_STATUS_SHOWABLE_AT_SF( '', [''] ), 'One TS_ID with status EMPTY_STRING will be hidden at SF' );
    ok( !$Package->IS_TSID_STATUS_SHOWABLE_AT_SF( '', [my $var = undef] ), 'One TS_ID with status UNDEFINED will be hidden at SF' );
    ## use critic
}

RunScript(
    'Sub' => \&Main,
);
